@@ -39,14 +39,14 @@
 #define DPERROR(x) /**/
 #endif
 #define CHECKPOINT PRINTERR_D("*** CHECKPOINT REACHED ***")
-#define SPOTVAR_LLX(x) PRINTERR_D(#x " = %llx", x)
-#define SPOTVAR_LLU(x) PRINTERR_D(#x " = %llu", x)
-#define SPOTVAR_LU(x) PRINTERR_D(#x " = %lu", x)
-#define SPOTVAR_D(x) PRINTERR_D(#x " = %lf", x)
-#define SPOTVAR_X(x) PRINTERR_D(#x " = 0x%x", x)
-#define SPOTVAR_I(x) PRINTERR_D(#x " = %i", x)
-#define SPOTVAR_P(x) PRINTERR_D(#x " = %p", x)
-#define SPOTVAR_S(x) PRINTERR_D(#x " = \"%s\"", x)
+#define SPOTVAR_LLX(x) PRINTERR_D(#x " = %llx", (unsigned long long) x)
+#define SPOTVAR_LLU(x) PRINTERR_D(#x " = %llu", (unsigned long long) x)
+#define SPOTVAR_LU(x) PRINTERR_D(#x " = %lu", (unsigned long) x)
+#define SPOTVAR_D(x) PRINTERR_D(#x " = %lf", (double) x)
+#define SPOTVAR_X(x) PRINTERR_D(#x " = 0x%x", (unsigned int) x)
+#define SPOTVAR_I(x) PRINTERR_D(#x " = %i", (int) x)
+#define SPOTVAR_P(x) PRINTERR_D(#x " = %p", (void *) x)
+#define SPOTVAR_S(x) PRINTERR_D(#x " = \"%s\"", (char *) x)
 
 
 #endif
