@@ -21,13 +21,12 @@ int main(int argc, char **argv) {
 
 	fclose_net(fp);
 
-	fp = fopen_net(argv[2], "r");
+	fp = fopen_net(argv[1], "r");
 	SPOTVAR_I(ftell_net(fp));
 	fread_ret = fread_net(buf, sizeof(buf[0]), 1, fp);
-	fseek_net(fp, 1, SEEK_CUR);
-	fread_ret = fread_net(buf + 1, sizeof(buf[0]), 1, fp);
-	SPOTVAR_I(ftell_net(fp));
-	buf[2] = '\0';
+	fseek_net(fp, 0, SEEK_END);
+	printf("len=%i\n", flength_net(fp));
+	buf[1] = '\0';
 
 	printf("two=%s\n", buf);
 
